@@ -7,14 +7,14 @@ from langgraph.prebuilt.interrupt import HumanInterrupt
 from langgraph.types import interrupt
 
 
-class InterrruptParams(TypedDict):
+class InterruptParams(TypedDict):
     tool_call_name: str
     tool_call_args: Dict[str, Any]
     tool: BaseTool
     config: RunnableConfig
 
 
-HumanInterruptHandler = Callable[[InterrruptParams], Any]
+HumanInterruptHandler = Callable[[InterruptParams], Any]
 
 
 @overload
@@ -22,7 +22,9 @@ def human_in_the_loop(
     func: Callable,
 ) -> BaseTool:
     """
-    Usage: @human_in_the_loop_sync
+    Decorator for adding human-in-the-loop review to a synchronous tool function.
+    
+    Usage: @human_in_the_loop
     """
     ...
 
@@ -33,7 +35,9 @@ def human_in_the_loop(
     handler: Optional[HumanInterruptHandler] = None,
 ) -> Callable[[Callable], BaseTool]:
     """
-    Usage: @human_in_the_loop_sync(interrupt_config={...})
+    Decorator for adding human-in-the-loop review to a synchronous tool function with custom handler.
+    
+    Usage: @human_in_the_loop(handler=custom_handler)
     """
     ...
 
@@ -43,6 +47,8 @@ def human_in_the_loop_async(
     func: Callable,
 ) -> BaseTool:
     """
+    Decorator for adding human-in-the-loop review to an asynchronous tool function.
+    
     Usage: @human_in_the_loop_async
     """
     ...
@@ -54,12 +60,14 @@ def human_in_the_loop_async(
     handler: Optional[HumanInterruptHandler] = None,
 ) -> Callable[[Callable], BaseTool]:
     """
-    Usage: @human_in_the_loop_async(interrupt_config={...})
+    Decorator for adding human-in-the-loop review to an asynchronous tool function with custom handler.
+    
+    Usage: @human_in_the_loop_async(handler=custom_handler)
     """
     ...
 
 
-def default_handler(params: InterrruptParams) -> Any:
+def default_handler(params: InterruptParams) -> Any:
     request: HumanInterrupt = {
         "action_request": {
             "action": params["tool_call_name"],
@@ -86,7 +94,7 @@ def default_handler(params: InterrruptParams) -> Any:
         raise ValueError(f"Unsupported interrupt response type: {response['type']}")
 
 
-async def default_handler_async(params: InterrruptParams) -> Any:
+async def default_handler_async(params: InterruptParams) -> Any:
     request: HumanInterrupt = {
         "action_request": {
             "action": params["tool_call_name"],
@@ -176,11 +184,11 @@ def human_in_the_loop_async(
 
     Supports both syntaxes:
         @human_in_the_loop_async
-        @human_in_the_loop_async(interrupt_config={...})
+        @human_in_the_loop_async(handler=fn)
 
     Args:
         func: The function to decorate. **Do not pass this directly.**
-        interrupt_config: Configuration for the human interrupt.
+        handler: Configuration for the human interrupt.
 
     Returns:
         If `func` is provided, returns the decorated BaseTool.
